@@ -1,27 +1,7 @@
-# Adafruit PN532 NFC/RFID control library.
-# Author: Tony DiCola
+# SPDX-FileCopyrightText: 2015-2018 Tony DiCola for Adafruit Industries
 #
-# The MIT License (MIT)
-#
-# Copyright (c) 2015-2018 Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 ``adafruit_pn532``
 ====================================================
@@ -172,8 +152,7 @@ class PN532:
     """PN532 driver base, must be extended for I2C/SPI/UART interfacing"""
 
     def __init__(self, *, debug=False, irq=None, reset=None):
-        """Create an instance of the PN532 class
-        """
+        """Create an instance of the PN532 class"""
         self.low_power = True
         self.debug = debug
         self._irq = irq
